# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/prediction/v1/prediction.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEgithub.com/metaprov/modelaapi/services/prediction/v1/prediction.proto\x12\x34github.com.metaprov.modelaapi.services.prediction.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1aIgithub.com/metaprov/modelaapi/pkg/apis/inference/v1alpha1/generated.proto\"\xfd\x01\n\x16ListPredictionsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12h\n\x06labels\x18\x02 \x03(\x0b\x32X.github.com.metaprov.modelaapi.services.prediction.v1.ListPredictionsRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x92\x01\n\x17ListPredictionsResponse\x12^\n\x0bpredictions\x18\x01 \x01(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.PredictionList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x1a\n\x18\x43reatePredictionResponse\"t\n\x17\x43reatePredictionRequest\x12Y\n\nprediction\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Prediction\"\xa4\x01\n\x17UpdatePredictionRequest\x12Y\n\nprediction\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Prediction\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x1a\n\x18UpdatePredictionResponse\"7\n\x14GetPredictionRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x80\x01\n\x15GetPredictionResponse\x12Y\n\nprediction\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Prediction\x12\x0c\n\x04yaml\x18\x02 \x01(\t\":\n\x17\x44\x65letePredictionRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1a\n\x18\x44\x65letePredictionResponse\"<\n\x19\x44ownloadPredictionRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\")\n\x1a\x44ownloadPredictionResponse\x12\x0b\n\x03raw\x18\x01 \x01(\x0c\"9\n\x16\x41\x62ortPredictionRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x19\n\x17\x41\x62ortPredictionResponse2\xb9\x0c\n\x11PredictionService\x12\xd3\x01\n\x0fListPredictions\x12L.github.com.metaprov.modelaapi.services.prediction.v1.ListPredictionsRequest\x1aM.github.com.metaprov.modelaapi.services.prediction.v1.ListPredictionsResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/v1/predictions/{namespace}\x12\xcd\x01\n\x10\x43reatePrediction\x12M.github.com.metaprov.modelaapi.services.prediction.v1.CreatePredictionRequest\x1aN.github.com.metaprov.modelaapi.services.prediction.v1.CreatePredictionResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/v1/predictions:\x01*\x12\xd4\x01\n\rGetPrediction\x12J.github.com.metaprov.modelaapi.services.prediction.v1.GetPredictionRequest\x1aK.github.com.metaprov.modelaapi.services.prediction.v1.GetPredictionResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/v1/predictions/{namespace}/{name}\x12\x88\x02\n\x10UpdatePrediction\x12M.github.com.metaprov.modelaapi.services.prediction.v1.UpdatePredictionRequest\x1aN.github.com.metaprov.modelaapi.services.prediction.v1.UpdatePredictionResponse\"U\x82\xd3\xe4\x93\x02O\x1aJ/v1/predictions/{prediction.metadata.namespace}/{prediction.metadata.name}:\x01*\x12\xdd\x01\n\x10\x44\x65letePrediction\x12M.github.com.metaprov.modelaapi.services.prediction.v1.DeletePredictionRequest\x1aN.github.com.metaprov.modelaapi.services.prediction.v1.DeletePredictionResponse\"*\x82\xd3\xe4\x93\x02$*\"/v1/predictions/{namespace}/{name}\x12\xe2\x01\n\x08\x44ownload\x12O.github.com.metaprov.modelaapi.services.prediction.v1.DownloadPredictionRequest\x1aP.github.com.metaprov.modelaapi.services.prediction.v1.DownloadPredictionResponse\"3\x82\xd3\xe4\x93\x02-\x12+/v1/predictions/{namespace}/{name}:download\x12\xd6\x01\n\x05\x41\x62ort\x12L.github.com.metaprov.modelaapi.services.prediction.v1.AbortPredictionRequest\x1aM.github.com.metaprov.modelaapi.services.prediction.v1.AbortPredictionResponse\"0\x82\xd3\xe4\x93\x02*\"(/v1/predictions/{namespace}/{name}:abortB6Z4github.com/metaprov/modelaapi/services/prediction/v1b\x06proto3')



_LISTPREDICTIONSREQUEST = DESCRIPTOR.message_types_by_name['ListPredictionsRequest']
_LISTPREDICTIONSREQUEST_LABELSENTRY = _LISTPREDICTIONSREQUEST.nested_types_by_name['LabelsEntry']
_LISTPREDICTIONSRESPONSE = DESCRIPTOR.message_types_by_name['ListPredictionsResponse']
_CREATEPREDICTIONRESPONSE = DESCRIPTOR.message_types_by_name['CreatePredictionResponse']
_CREATEPREDICTIONREQUEST = DESCRIPTOR.message_types_by_name['CreatePredictionRequest']
_UPDATEPREDICTIONREQUEST = DESCRIPTOR.message_types_by_name['UpdatePredictionRequest']
_UPDATEPREDICTIONRESPONSE = DESCRIPTOR.message_types_by_name['UpdatePredictionResponse']
_GETPREDICTIONREQUEST = DESCRIPTOR.message_types_by_name['GetPredictionRequest']
_GETPREDICTIONRESPONSE = DESCRIPTOR.message_types_by_name['GetPredictionResponse']
_DELETEPREDICTIONREQUEST = DESCRIPTOR.message_types_by_name['DeletePredictionRequest']
_DELETEPREDICTIONRESPONSE = DESCRIPTOR.message_types_by_name['DeletePredictionResponse']
_DOWNLOADPREDICTIONREQUEST = DESCRIPTOR.message_types_by_name['DownloadPredictionRequest']
_DOWNLOADPREDICTIONRESPONSE = DESCRIPTOR.message_types_by_name['DownloadPredictionResponse']
_ABORTPREDICTIONREQUEST = DESCRIPTOR.message_types_by_name['AbortPredictionRequest']
_ABORTPREDICTIONRESPONSE = DESCRIPTOR.message_types_by_name['AbortPredictionResponse']
ListPredictionsRequest = _reflection.GeneratedProtocolMessageType('ListPredictionsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTPREDICTIONSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.prediction.v1.prediction_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.prediction.v1.ListPredictionsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTPREDICTIONSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.prediction.v1.prediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.prediction.v1.ListPredictionsRequest)
  })
_sym_db.RegisterMessage(ListPredictionsRequest)
_sym_db.RegisterMessage(ListPredictionsRequest.LabelsEntry)

ListPredictionsResponse = _reflection.GeneratedProtocolMessageType('ListPredictionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPREDICTIONSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.prediction.v1.prediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.prediction.v1.ListPredictionsResponse)
  })
_sym_db.RegisterMessage(ListPredictionsResponse)

CreatePredictionResponse = _reflection.GeneratedProtocolMessageType('CreatePredictionResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPREDICTIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.prediction.v1.prediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.prediction.v1.CreatePredictionResponse)
  })
_sym_db.RegisterMessage(CreatePredictionResponse)

CreatePredictionRequest = _reflection.GeneratedProtocolMessageType('CreatePredictionRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPREDICTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.prediction.v1.prediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.prediction.v1.CreatePredictionRequest)
  })
_sym_db.RegisterMessage(CreatePredictionRequest)

UpdatePredictionRequest = _reflection.GeneratedProtocolMessageType('UpdatePredictionRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPREDICTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.prediction.v1.prediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.prediction.v1.UpdatePredictionRequest)
  })
_sym_db.RegisterMessage(UpdatePredictionRequest)

UpdatePredictionResponse = _reflection.GeneratedProtocolMessageType('UpdatePredictionResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPREDICTIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.prediction.v1.prediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.prediction.v1.UpdatePredictionResponse)
  })
_sym_db.RegisterMessage(UpdatePredictionResponse)

GetPredictionRequest = _reflection.GeneratedProtocolMessageType('GetPredictionRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPREDICTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.prediction.v1.prediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.prediction.v1.GetPredictionRequest)
  })
_sym_db.RegisterMessage(GetPredictionRequest)

GetPredictionResponse = _reflection.GeneratedProtocolMessageType('GetPredictionResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETPREDICTIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.prediction.v1.prediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.prediction.v1.GetPredictionResponse)
  })
_sym_db.RegisterMessage(GetPredictionResponse)

DeletePredictionRequest = _reflection.GeneratedProtocolMessageType('DeletePredictionRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPREDICTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.prediction.v1.prediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.prediction.v1.DeletePredictionRequest)
  })
_sym_db.RegisterMessage(DeletePredictionRequest)

DeletePredictionResponse = _reflection.GeneratedProtocolMessageType('DeletePredictionResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPREDICTIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.prediction.v1.prediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.prediction.v1.DeletePredictionResponse)
  })
_sym_db.RegisterMessage(DeletePredictionResponse)

DownloadPredictionRequest = _reflection.GeneratedProtocolMessageType('DownloadPredictionRequest', (_message.Message,), {
  'DESCRIPTOR' : _DOWNLOADPREDICTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.prediction.v1.prediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.prediction.v1.DownloadPredictionRequest)
  })
_sym_db.RegisterMessage(DownloadPredictionRequest)

DownloadPredictionResponse = _reflection.GeneratedProtocolMessageType('DownloadPredictionResponse', (_message.Message,), {
  'DESCRIPTOR' : _DOWNLOADPREDICTIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.prediction.v1.prediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.prediction.v1.DownloadPredictionResponse)
  })
_sym_db.RegisterMessage(DownloadPredictionResponse)

AbortPredictionRequest = _reflection.GeneratedProtocolMessageType('AbortPredictionRequest', (_message.Message,), {
  'DESCRIPTOR' : _ABORTPREDICTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.prediction.v1.prediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.prediction.v1.AbortPredictionRequest)
  })
_sym_db.RegisterMessage(AbortPredictionRequest)

AbortPredictionResponse = _reflection.GeneratedProtocolMessageType('AbortPredictionResponse', (_message.Message,), {
  'DESCRIPTOR' : _ABORTPREDICTIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.prediction.v1.prediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.prediction.v1.AbortPredictionResponse)
  })
_sym_db.RegisterMessage(AbortPredictionResponse)

_PREDICTIONSERVICE = DESCRIPTOR.services_by_name['PredictionService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z4github.com/metaprov/modelaapi/services/prediction/v1'
  _LISTPREDICTIONSREQUEST_LABELSENTRY._options = None
  _LISTPREDICTIONSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _PREDICTIONSERVICE.methods_by_name['ListPredictions']._options = None
  _PREDICTIONSERVICE.methods_by_name['ListPredictions']._serialized_options = b'\202\323\344\223\002\035\022\033/v1/predictions/{namespace}'
  _PREDICTIONSERVICE.methods_by_name['CreatePrediction']._options = None
  _PREDICTIONSERVICE.methods_by_name['CreatePrediction']._serialized_options = b'\202\323\344\223\002\024\"\017/v1/predictions:\001*'
  _PREDICTIONSERVICE.methods_by_name['GetPrediction']._options = None
  _PREDICTIONSERVICE.methods_by_name['GetPrediction']._serialized_options = b'\202\323\344\223\002$\022\"/v1/predictions/{namespace}/{name}'
  _PREDICTIONSERVICE.methods_by_name['UpdatePrediction']._options = None
  _PREDICTIONSERVICE.methods_by_name['UpdatePrediction']._serialized_options = b'\202\323\344\223\002O\032J/v1/predictions/{prediction.metadata.namespace}/{prediction.metadata.name}:\001*'
  _PREDICTIONSERVICE.methods_by_name['DeletePrediction']._options = None
  _PREDICTIONSERVICE.methods_by_name['DeletePrediction']._serialized_options = b'\202\323\344\223\002$*\"/v1/predictions/{namespace}/{name}'
  _PREDICTIONSERVICE.methods_by_name['Download']._options = None
  _PREDICTIONSERVICE.methods_by_name['Download']._serialized_options = b'\202\323\344\223\002-\022+/v1/predictions/{namespace}/{name}:download'
  _PREDICTIONSERVICE.methods_by_name['Abort']._options = None
  _PREDICTIONSERVICE.methods_by_name['Abort']._serialized_options = b'\202\323\344\223\002*\"(/v1/predictions/{namespace}/{name}:abort'
  _LISTPREDICTIONSREQUEST._serialized_start=267
  _LISTPREDICTIONSREQUEST._serialized_end=520
  _LISTPREDICTIONSREQUEST_LABELSENTRY._serialized_start=475
  _LISTPREDICTIONSREQUEST_LABELSENTRY._serialized_end=520
  _LISTPREDICTIONSRESPONSE._serialized_start=523
  _LISTPREDICTIONSRESPONSE._serialized_end=669
  _CREATEPREDICTIONRESPONSE._serialized_start=671
  _CREATEPREDICTIONRESPONSE._serialized_end=697
  _CREATEPREDICTIONREQUEST._serialized_start=699
  _CREATEPREDICTIONREQUEST._serialized_end=815
  _UPDATEPREDICTIONREQUEST._serialized_start=818
  _UPDATEPREDICTIONREQUEST._serialized_end=982
  _UPDATEPREDICTIONRESPONSE._serialized_start=984
  _UPDATEPREDICTIONRESPONSE._serialized_end=1010
  _GETPREDICTIONREQUEST._serialized_start=1012
  _GETPREDICTIONREQUEST._serialized_end=1067
  _GETPREDICTIONRESPONSE._serialized_start=1070
  _GETPREDICTIONRESPONSE._serialized_end=1198
  _DELETEPREDICTIONREQUEST._serialized_start=1200
  _DELETEPREDICTIONREQUEST._serialized_end=1258
  _DELETEPREDICTIONRESPONSE._serialized_start=1260
  _DELETEPREDICTIONRESPONSE._serialized_end=1286
  _DOWNLOADPREDICTIONREQUEST._serialized_start=1288
  _DOWNLOADPREDICTIONREQUEST._serialized_end=1348
  _DOWNLOADPREDICTIONRESPONSE._serialized_start=1350
  _DOWNLOADPREDICTIONRESPONSE._serialized_end=1391
  _ABORTPREDICTIONREQUEST._serialized_start=1393
  _ABORTPREDICTIONREQUEST._serialized_end=1450
  _ABORTPREDICTIONRESPONSE._serialized_start=1452
  _ABORTPREDICTIONRESPONSE._serialized_end=1477
  _PREDICTIONSERVICE._serialized_start=1480
  _PREDICTIONSERVICE._serialized_end=3073
# @@protoc_insertion_point(module_scope)
