# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/modelasystem/v1/modelasystem.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.services.common.v1 import common_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nIgithub.com/metaprov/modelaapi/services/modelasystem/v1/modelasystem.proto\x12\x36github.com.metaprov.modelaapi.services.modelasystem.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\x1a=github.com/metaprov/modelaapi/services/common/v1/common.proto\x1a google/protobuf/field_mask.proto\"\xca\x01\n\x18ListModelaSystemsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12l\n\x06labels\x18\x02 \x03(\x0b\x32\\.github.com.metaprov.modelaapi.services.modelasystem.v1.ListModelaSystemsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"{\n\x19ListModelaSystemsResponse\x12^\n\rmodelasystems\x18\x01 \x01(\x0b\x32G.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ModelaSystemList\"\x16\n\x14ModelaSystemResponse\"\x88\x01\n\x19\x43reateModelaSystemRequest\x12Y\n\x0cmodelasystem\x18\x01 \x01(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ModelaSystem\x12\x10\n\x08password\x18\x02 \x01(\t\"\x1c\n\x1a\x43reateModelaSystemResponse\"\xa6\x01\n\x19UpdateModelaSystemRequest\x12Y\n\x0cmodelasystem\x18\x01 \x01(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ModelaSystem\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x1c\n\x1aUpdateModelaSystemResponse\"9\n\x16GetModelaSystemRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x82\x01\n\x17GetModelaSystemResponse\x12Y\n\x0cmodelasystem\x18\x01 \x01(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ModelaSystem\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"C\n GetModelaSystemNamespacesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"x\n!GetModelaSystemNamespacesResponse\x12S\n\nnamespaces\x18\x01 \x03(\x0b\x32?.github.com.metaprov.modelaapi.services.common.v1.NamespaceInfo\"<\n\x19\x44\x65leteModelaSystemRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1c\n\x1a\x44\x65leteModelaSystemResponse\"\x1c\n\x1aModelaSystemCreateResponse\"\x10\n\x0eLogoutResponse\"\x17\n\x15ResetPasswordResponse\"?\n\x1cModelaSystemGetByNameRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"*\n\x19ModelaSystemLogoutRequest\x12\r\n\x05token\x18\x01 \x01(\t\"I\n\x16\x44ownloadLogFileRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0e\n\x06\x62ucket\x18\x02 \x01(\t\x12\x0c\n\x04path\x18\x03 \x01(\t\")\n\x17\x44ownloadLogFileResponse\x12\x0e\n\x06result\x18\x01 \x01(\x0c\"H\n\x15\x42\x61\x63kupDatabaseRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0e\n\x06\x62ucket\x18\x02 \x01(\t\x12\x0c\n\x04path\x18\x03 \x01(\t\"&\n\x16\x42\x61\x63kupDatabaseResponse\x12\x0c\n\x04path\x18\x01 \x01(\t\"D\n\x11\x42\x61\x63kupEtcdRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0e\n\x06\x62ucket\x18\x02 \x01(\t\x12\x0c\n\x04path\x18\x03 \x01(\t\"\"\n\x12\x42\x61\x63kupEtcdResponse\x12\x0c\n\x04path\x18\x01 \x01(\t2\xb2\x0e\n\x13ModelaSystemService\x12\xdf\x01\n\x11ListModelaSystems\x12P.github.com.metaprov.modelaapi.services.modelasystem.v1.ListModelaSystemsRequest\x1aQ.github.com.metaprov.modelaapi.services.modelasystem.v1.ListModelaSystemsResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/v1/modelasystems/{namespace}\x12\xd9\x01\n\x12\x43reateModelaSystem\x12Q.github.com.metaprov.modelaapi.services.modelasystem.v1.CreateModelaSystemRequest\x1aR.github.com.metaprov.modelaapi.services.modelasystem.v1.CreateModelaSystemResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\"\x11/v1/modelasystems:\x01*\x12\xe0\x01\n\x0fGetModelaSystem\x12N.github.com.metaprov.modelaapi.services.modelasystem.v1.GetModelaSystemRequest\x1aO.github.com.metaprov.modelaapi.services.modelasystem.v1.GetModelaSystemResponse\",\x82\xd3\xe4\x93\x02&\x12$/v1/modelasystems/{namespace}/{name}\x12\x98\x02\n\x12UpdateModelaSystem\x12Q.github.com.metaprov.modelaapi.services.modelasystem.v1.UpdateModelaSystemRequest\x1aR.github.com.metaprov.modelaapi.services.modelasystem.v1.UpdateModelaSystemResponse\"[\x82\xd3\xe4\x93\x02U\x1aP/v1/modelasystems/{modelasystem.metadata.namespace}/{modelasystem.metadata.name}:\x01*\x12\xe9\x01\n\x12\x44\x65leteModelaSystem\x12Q.github.com.metaprov.modelaapi.services.modelasystem.v1.DeleteModelaSystemRequest\x1aR.github.com.metaprov.modelaapi.services.modelasystem.v1.DeleteModelaSystemResponse\",\x82\xd3\xe4\x93\x02&*$/v1/modelasystems/{namespace}/{name}\x12\xd4\x01\n\x0f\x44ownloadLogfile\x12N.github.com.metaprov.modelaapi.services.modelasystem.v1.DownloadLogFileRequest\x1aO.github.com.metaprov.modelaapi.services.modelasystem.v1.DownloadLogFileResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/v1/download/{namespace}\x12\xd1\x01\n\x0e\x42\x61\x63kupDatabase\x12M.github.com.metaprov.modelaapi.services.modelasystem.v1.BackupDatabaseRequest\x1aN.github.com.metaprov.modelaapi.services.modelasystem.v1.BackupDatabaseResponse\" \x82\xd3\xe4\x93\x02\x1a\"\x18/v1/backupdb/{namespace}\x12\xc7\x01\n\nBackupEtcd\x12I.github.com.metaprov.modelaapi.services.modelasystem.v1.BackupEtcdRequest\x1aJ.github.com.metaprov.modelaapi.services.modelasystem.v1.BackupEtcdResponse\"\"\x82\xd3\xe4\x93\x02\x1c\"\x1a/v1/backupetcd/{namespace}B8Z6github.com/metaprov/modelaapi/services/modelasystem/v1b\x06proto3')



_LISTMODELASYSTEMSREQUEST = DESCRIPTOR.message_types_by_name['ListModelaSystemsRequest']
_LISTMODELASYSTEMSREQUEST_LABELSENTRY = _LISTMODELASYSTEMSREQUEST.nested_types_by_name['LabelsEntry']
_LISTMODELASYSTEMSRESPONSE = DESCRIPTOR.message_types_by_name['ListModelaSystemsResponse']
_MODELASYSTEMRESPONSE = DESCRIPTOR.message_types_by_name['ModelaSystemResponse']
_CREATEMODELASYSTEMREQUEST = DESCRIPTOR.message_types_by_name['CreateModelaSystemRequest']
_CREATEMODELASYSTEMRESPONSE = DESCRIPTOR.message_types_by_name['CreateModelaSystemResponse']
_UPDATEMODELASYSTEMREQUEST = DESCRIPTOR.message_types_by_name['UpdateModelaSystemRequest']
_UPDATEMODELASYSTEMRESPONSE = DESCRIPTOR.message_types_by_name['UpdateModelaSystemResponse']
_GETMODELASYSTEMREQUEST = DESCRIPTOR.message_types_by_name['GetModelaSystemRequest']
_GETMODELASYSTEMRESPONSE = DESCRIPTOR.message_types_by_name['GetModelaSystemResponse']
_GETMODELASYSTEMNAMESPACESREQUEST = DESCRIPTOR.message_types_by_name['GetModelaSystemNamespacesRequest']
_GETMODELASYSTEMNAMESPACESRESPONSE = DESCRIPTOR.message_types_by_name['GetModelaSystemNamespacesResponse']
_DELETEMODELASYSTEMREQUEST = DESCRIPTOR.message_types_by_name['DeleteModelaSystemRequest']
_DELETEMODELASYSTEMRESPONSE = DESCRIPTOR.message_types_by_name['DeleteModelaSystemResponse']
_MODELASYSTEMCREATERESPONSE = DESCRIPTOR.message_types_by_name['ModelaSystemCreateResponse']
_LOGOUTRESPONSE = DESCRIPTOR.message_types_by_name['LogoutResponse']
_RESETPASSWORDRESPONSE = DESCRIPTOR.message_types_by_name['ResetPasswordResponse']
_MODELASYSTEMGETBYNAMEREQUEST = DESCRIPTOR.message_types_by_name['ModelaSystemGetByNameRequest']
_MODELASYSTEMLOGOUTREQUEST = DESCRIPTOR.message_types_by_name['ModelaSystemLogoutRequest']
_DOWNLOADLOGFILEREQUEST = DESCRIPTOR.message_types_by_name['DownloadLogFileRequest']
_DOWNLOADLOGFILERESPONSE = DESCRIPTOR.message_types_by_name['DownloadLogFileResponse']
_BACKUPDATABASEREQUEST = DESCRIPTOR.message_types_by_name['BackupDatabaseRequest']
_BACKUPDATABASERESPONSE = DESCRIPTOR.message_types_by_name['BackupDatabaseResponse']
_BACKUPETCDREQUEST = DESCRIPTOR.message_types_by_name['BackupEtcdRequest']
_BACKUPETCDRESPONSE = DESCRIPTOR.message_types_by_name['BackupEtcdResponse']
ListModelaSystemsRequest = _reflection.GeneratedProtocolMessageType('ListModelaSystemsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTMODELASYSTEMSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.modelasystem.v1.modelasystem_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelasystem.v1.ListModelaSystemsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTMODELASYSTEMSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelasystem.v1.modelasystem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelasystem.v1.ListModelaSystemsRequest)
  })
_sym_db.RegisterMessage(ListModelaSystemsRequest)
_sym_db.RegisterMessage(ListModelaSystemsRequest.LabelsEntry)

ListModelaSystemsResponse = _reflection.GeneratedProtocolMessageType('ListModelaSystemsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTMODELASYSTEMSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelasystem.v1.modelasystem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelasystem.v1.ListModelaSystemsResponse)
  })
_sym_db.RegisterMessage(ListModelaSystemsResponse)

ModelaSystemResponse = _reflection.GeneratedProtocolMessageType('ModelaSystemResponse', (_message.Message,), {
  'DESCRIPTOR' : _MODELASYSTEMRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelasystem.v1.modelasystem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelasystem.v1.ModelaSystemResponse)
  })
_sym_db.RegisterMessage(ModelaSystemResponse)

CreateModelaSystemRequest = _reflection.GeneratedProtocolMessageType('CreateModelaSystemRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELASYSTEMREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelasystem.v1.modelasystem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelasystem.v1.CreateModelaSystemRequest)
  })
_sym_db.RegisterMessage(CreateModelaSystemRequest)

CreateModelaSystemResponse = _reflection.GeneratedProtocolMessageType('CreateModelaSystemResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELASYSTEMRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelasystem.v1.modelasystem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelasystem.v1.CreateModelaSystemResponse)
  })
_sym_db.RegisterMessage(CreateModelaSystemResponse)

UpdateModelaSystemRequest = _reflection.GeneratedProtocolMessageType('UpdateModelaSystemRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMODELASYSTEMREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelasystem.v1.modelasystem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelasystem.v1.UpdateModelaSystemRequest)
  })
_sym_db.RegisterMessage(UpdateModelaSystemRequest)

UpdateModelaSystemResponse = _reflection.GeneratedProtocolMessageType('UpdateModelaSystemResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMODELASYSTEMRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelasystem.v1.modelasystem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelasystem.v1.UpdateModelaSystemResponse)
  })
_sym_db.RegisterMessage(UpdateModelaSystemResponse)

GetModelaSystemRequest = _reflection.GeneratedProtocolMessageType('GetModelaSystemRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELASYSTEMREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelasystem.v1.modelasystem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelasystem.v1.GetModelaSystemRequest)
  })
_sym_db.RegisterMessage(GetModelaSystemRequest)

GetModelaSystemResponse = _reflection.GeneratedProtocolMessageType('GetModelaSystemResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELASYSTEMRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelasystem.v1.modelasystem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelasystem.v1.GetModelaSystemResponse)
  })
_sym_db.RegisterMessage(GetModelaSystemResponse)

GetModelaSystemNamespacesRequest = _reflection.GeneratedProtocolMessageType('GetModelaSystemNamespacesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELASYSTEMNAMESPACESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelasystem.v1.modelasystem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelasystem.v1.GetModelaSystemNamespacesRequest)
  })
_sym_db.RegisterMessage(GetModelaSystemNamespacesRequest)

GetModelaSystemNamespacesResponse = _reflection.GeneratedProtocolMessageType('GetModelaSystemNamespacesResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELASYSTEMNAMESPACESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelasystem.v1.modelasystem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelasystem.v1.GetModelaSystemNamespacesResponse)
  })
_sym_db.RegisterMessage(GetModelaSystemNamespacesResponse)

DeleteModelaSystemRequest = _reflection.GeneratedProtocolMessageType('DeleteModelaSystemRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODELASYSTEMREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelasystem.v1.modelasystem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelasystem.v1.DeleteModelaSystemRequest)
  })
_sym_db.RegisterMessage(DeleteModelaSystemRequest)

DeleteModelaSystemResponse = _reflection.GeneratedProtocolMessageType('DeleteModelaSystemResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODELASYSTEMRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelasystem.v1.modelasystem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelasystem.v1.DeleteModelaSystemResponse)
  })
_sym_db.RegisterMessage(DeleteModelaSystemResponse)

ModelaSystemCreateResponse = _reflection.GeneratedProtocolMessageType('ModelaSystemCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _MODELASYSTEMCREATERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelasystem.v1.modelasystem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelasystem.v1.ModelaSystemCreateResponse)
  })
_sym_db.RegisterMessage(ModelaSystemCreateResponse)

LogoutResponse = _reflection.GeneratedProtocolMessageType('LogoutResponse', (_message.Message,), {
  'DESCRIPTOR' : _LOGOUTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelasystem.v1.modelasystem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelasystem.v1.LogoutResponse)
  })
_sym_db.RegisterMessage(LogoutResponse)

ResetPasswordResponse = _reflection.GeneratedProtocolMessageType('ResetPasswordResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESETPASSWORDRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelasystem.v1.modelasystem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelasystem.v1.ResetPasswordResponse)
  })
_sym_db.RegisterMessage(ResetPasswordResponse)

ModelaSystemGetByNameRequest = _reflection.GeneratedProtocolMessageType('ModelaSystemGetByNameRequest', (_message.Message,), {
  'DESCRIPTOR' : _MODELASYSTEMGETBYNAMEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelasystem.v1.modelasystem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelasystem.v1.ModelaSystemGetByNameRequest)
  })
_sym_db.RegisterMessage(ModelaSystemGetByNameRequest)

ModelaSystemLogoutRequest = _reflection.GeneratedProtocolMessageType('ModelaSystemLogoutRequest', (_message.Message,), {
  'DESCRIPTOR' : _MODELASYSTEMLOGOUTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelasystem.v1.modelasystem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelasystem.v1.ModelaSystemLogoutRequest)
  })
_sym_db.RegisterMessage(ModelaSystemLogoutRequest)

DownloadLogFileRequest = _reflection.GeneratedProtocolMessageType('DownloadLogFileRequest', (_message.Message,), {
  'DESCRIPTOR' : _DOWNLOADLOGFILEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelasystem.v1.modelasystem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelasystem.v1.DownloadLogFileRequest)
  })
_sym_db.RegisterMessage(DownloadLogFileRequest)

DownloadLogFileResponse = _reflection.GeneratedProtocolMessageType('DownloadLogFileResponse', (_message.Message,), {
  'DESCRIPTOR' : _DOWNLOADLOGFILERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelasystem.v1.modelasystem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelasystem.v1.DownloadLogFileResponse)
  })
_sym_db.RegisterMessage(DownloadLogFileResponse)

BackupDatabaseRequest = _reflection.GeneratedProtocolMessageType('BackupDatabaseRequest', (_message.Message,), {
  'DESCRIPTOR' : _BACKUPDATABASEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelasystem.v1.modelasystem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelasystem.v1.BackupDatabaseRequest)
  })
_sym_db.RegisterMessage(BackupDatabaseRequest)

BackupDatabaseResponse = _reflection.GeneratedProtocolMessageType('BackupDatabaseResponse', (_message.Message,), {
  'DESCRIPTOR' : _BACKUPDATABASERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelasystem.v1.modelasystem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelasystem.v1.BackupDatabaseResponse)
  })
_sym_db.RegisterMessage(BackupDatabaseResponse)

BackupEtcdRequest = _reflection.GeneratedProtocolMessageType('BackupEtcdRequest', (_message.Message,), {
  'DESCRIPTOR' : _BACKUPETCDREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelasystem.v1.modelasystem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelasystem.v1.BackupEtcdRequest)
  })
_sym_db.RegisterMessage(BackupEtcdRequest)

BackupEtcdResponse = _reflection.GeneratedProtocolMessageType('BackupEtcdResponse', (_message.Message,), {
  'DESCRIPTOR' : _BACKUPETCDRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelasystem.v1.modelasystem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelasystem.v1.BackupEtcdResponse)
  })
_sym_db.RegisterMessage(BackupEtcdResponse)

_MODELASYSTEMSERVICE = DESCRIPTOR.services_by_name['ModelaSystemService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z6github.com/metaprov/modelaapi/services/modelasystem/v1'
  _LISTMODELASYSTEMSREQUEST_LABELSENTRY._options = None
  _LISTMODELASYSTEMSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _MODELASYSTEMSERVICE.methods_by_name['ListModelaSystems']._options = None
  _MODELASYSTEMSERVICE.methods_by_name['ListModelaSystems']._serialized_options = b'\202\323\344\223\002\037\022\035/v1/modelasystems/{namespace}'
  _MODELASYSTEMSERVICE.methods_by_name['CreateModelaSystem']._options = None
  _MODELASYSTEMSERVICE.methods_by_name['CreateModelaSystem']._serialized_options = b'\202\323\344\223\002\026\"\021/v1/modelasystems:\001*'
  _MODELASYSTEMSERVICE.methods_by_name['GetModelaSystem']._options = None
  _MODELASYSTEMSERVICE.methods_by_name['GetModelaSystem']._serialized_options = b'\202\323\344\223\002&\022$/v1/modelasystems/{namespace}/{name}'
  _MODELASYSTEMSERVICE.methods_by_name['UpdateModelaSystem']._options = None
  _MODELASYSTEMSERVICE.methods_by_name['UpdateModelaSystem']._serialized_options = b'\202\323\344\223\002U\032P/v1/modelasystems/{modelasystem.metadata.namespace}/{modelasystem.metadata.name}:\001*'
  _MODELASYSTEMSERVICE.methods_by_name['DeleteModelaSystem']._options = None
  _MODELASYSTEMSERVICE.methods_by_name['DeleteModelaSystem']._serialized_options = b'\202\323\344\223\002&*$/v1/modelasystems/{namespace}/{name}'
  _MODELASYSTEMSERVICE.methods_by_name['DownloadLogfile']._options = None
  _MODELASYSTEMSERVICE.methods_by_name['DownloadLogfile']._serialized_options = b'\202\323\344\223\002\032\022\030/v1/download/{namespace}'
  _MODELASYSTEMSERVICE.methods_by_name['BackupDatabase']._options = None
  _MODELASYSTEMSERVICE.methods_by_name['BackupDatabase']._serialized_options = b'\202\323\344\223\002\032\"\030/v1/backupdb/{namespace}'
  _MODELASYSTEMSERVICE.methods_by_name['BackupEtcd']._options = None
  _MODELASYSTEMSERVICE.methods_by_name['BackupEtcd']._serialized_options = b'\202\323\344\223\002\034\"\032/v1/backupetcd/{namespace}'
  _LISTMODELASYSTEMSREQUEST._serialized_start=332
  _LISTMODELASYSTEMSREQUEST._serialized_end=534
  _LISTMODELASYSTEMSREQUEST_LABELSENTRY._serialized_start=489
  _LISTMODELASYSTEMSREQUEST_LABELSENTRY._serialized_end=534
  _LISTMODELASYSTEMSRESPONSE._serialized_start=536
  _LISTMODELASYSTEMSRESPONSE._serialized_end=659
  _MODELASYSTEMRESPONSE._serialized_start=661
  _MODELASYSTEMRESPONSE._serialized_end=683
  _CREATEMODELASYSTEMREQUEST._serialized_start=686
  _CREATEMODELASYSTEMREQUEST._serialized_end=822
  _CREATEMODELASYSTEMRESPONSE._serialized_start=824
  _CREATEMODELASYSTEMRESPONSE._serialized_end=852
  _UPDATEMODELASYSTEMREQUEST._serialized_start=855
  _UPDATEMODELASYSTEMREQUEST._serialized_end=1021
  _UPDATEMODELASYSTEMRESPONSE._serialized_start=1023
  _UPDATEMODELASYSTEMRESPONSE._serialized_end=1051
  _GETMODELASYSTEMREQUEST._serialized_start=1053
  _GETMODELASYSTEMREQUEST._serialized_end=1110
  _GETMODELASYSTEMRESPONSE._serialized_start=1113
  _GETMODELASYSTEMRESPONSE._serialized_end=1243
  _GETMODELASYSTEMNAMESPACESREQUEST._serialized_start=1245
  _GETMODELASYSTEMNAMESPACESREQUEST._serialized_end=1312
  _GETMODELASYSTEMNAMESPACESRESPONSE._serialized_start=1314
  _GETMODELASYSTEMNAMESPACESRESPONSE._serialized_end=1434
  _DELETEMODELASYSTEMREQUEST._serialized_start=1436
  _DELETEMODELASYSTEMREQUEST._serialized_end=1496
  _DELETEMODELASYSTEMRESPONSE._serialized_start=1498
  _DELETEMODELASYSTEMRESPONSE._serialized_end=1526
  _MODELASYSTEMCREATERESPONSE._serialized_start=1528
  _MODELASYSTEMCREATERESPONSE._serialized_end=1556
  _LOGOUTRESPONSE._serialized_start=1558
  _LOGOUTRESPONSE._serialized_end=1574
  _RESETPASSWORDRESPONSE._serialized_start=1576
  _RESETPASSWORDRESPONSE._serialized_end=1599
  _MODELASYSTEMGETBYNAMEREQUEST._serialized_start=1601
  _MODELASYSTEMGETBYNAMEREQUEST._serialized_end=1664
  _MODELASYSTEMLOGOUTREQUEST._serialized_start=1666
  _MODELASYSTEMLOGOUTREQUEST._serialized_end=1708
  _DOWNLOADLOGFILEREQUEST._serialized_start=1710
  _DOWNLOADLOGFILEREQUEST._serialized_end=1783
  _DOWNLOADLOGFILERESPONSE._serialized_start=1785
  _DOWNLOADLOGFILERESPONSE._serialized_end=1826
  _BACKUPDATABASEREQUEST._serialized_start=1828
  _BACKUPDATABASEREQUEST._serialized_end=1900
  _BACKUPDATABASERESPONSE._serialized_start=1902
  _BACKUPDATABASERESPONSE._serialized_end=1940
  _BACKUPETCDREQUEST._serialized_start=1942
  _BACKUPETCDREQUEST._serialized_end=2010
  _BACKUPETCDRESPONSE._serialized_start=2012
  _BACKUPETCDRESPONSE._serialized_end=2046
  _MODELASYSTEMSERVICE._serialized_start=2049
  _MODELASYSTEMSERVICE._serialized_end=3891
# @@protoc_insertion_point(module_scope)
