# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.userroleclass.v1 import userroleclass_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2


class UserRoleClassServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListUserRoleClasses = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.userroleclass.v1.UserRoleClassService/ListUserRoleClasses',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.ListUserRoleClassesRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.ListUserRoleClassesResponse.FromString,
                )
        self.CreateUserRoleClass = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.userroleclass.v1.UserRoleClassService/CreateUserRoleClass',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.CreateUserRoleClassRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.CreateUserRoleClassResponse.FromString,
                )
        self.GetUserRoleClass = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.userroleclass.v1.UserRoleClassService/GetUserRoleClass',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.GetUserRoleClassRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.GetUserRoleClassResponse.FromString,
                )
        self.UpdateUserRoleClass = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.userroleclass.v1.UserRoleClassService/UpdateUserRoleClass',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.UpdateUserRoleClassRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.UpdateUserRoleClassResponse.FromString,
                )
        self.DeleteUserRoleClass = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.userroleclass.v1.UserRoleClassService/DeleteUserRoleClass',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.DeleteUserRoleClassRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.DeleteUserRoleClassResponse.FromString,
                )


class UserRoleClassServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListUserRoleClasses(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateUserRoleClass(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUserRoleClass(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateUserRoleClass(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteUserRoleClass(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_UserRoleClassServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListUserRoleClasses': grpc.unary_unary_rpc_method_handler(
                    servicer.ListUserRoleClasses,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.ListUserRoleClassesRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.ListUserRoleClassesResponse.SerializeToString,
            ),
            'CreateUserRoleClass': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateUserRoleClass,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.CreateUserRoleClassRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.CreateUserRoleClassResponse.SerializeToString,
            ),
            'GetUserRoleClass': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUserRoleClass,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.GetUserRoleClassRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.GetUserRoleClassResponse.SerializeToString,
            ),
            'UpdateUserRoleClass': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateUserRoleClass,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.UpdateUserRoleClassRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.UpdateUserRoleClassResponse.SerializeToString,
            ),
            'DeleteUserRoleClass': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteUserRoleClass,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.DeleteUserRoleClassRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.DeleteUserRoleClassResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.userroleclass.v1.UserRoleClassService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class UserRoleClassService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListUserRoleClasses(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.userroleclass.v1.UserRoleClassService/ListUserRoleClasses',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.ListUserRoleClassesRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.ListUserRoleClassesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateUserRoleClass(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.userroleclass.v1.UserRoleClassService/CreateUserRoleClass',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.CreateUserRoleClassRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.CreateUserRoleClassResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUserRoleClass(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.userroleclass.v1.UserRoleClassService/GetUserRoleClass',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.GetUserRoleClassRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.GetUserRoleClassResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateUserRoleClass(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.userroleclass.v1.UserRoleClassService/UpdateUserRoleClass',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.UpdateUserRoleClassRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.UpdateUserRoleClassResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteUserRoleClass(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.userroleclass.v1.UserRoleClassService/DeleteUserRoleClass',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.DeleteUserRoleClassRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_userroleclass_dot_v1_dot_userroleclass__pb2.DeleteUserRoleClassResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
