# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/cronreport/v1/cronreport.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEgithub.com/metaprov/modelaapi/services/cronreport/v1/cronreport.proto\x12\x34github.com.metaprov.modelaapi.services.cronreport.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1aHgithub.com/metaprov/modelaapi/pkg/apis/training/v1alpha1/generated.proto\"\xfd\x01\n\x16ListCronReportsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12h\n\x06labels\x18\x02 \x03(\x0b\x32X.github.com.metaprov.modelaapi.services.cronreport.v1.ListCronReportsRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x91\x01\n\x17ListCronReportsResponse\x12]\n\x0b\x63ronreports\x18\x01 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.CronReportList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x1a\n\x18\x43reateCronReportResponse\"s\n\x17\x43reateCronReportRequest\x12X\n\ncronreport\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.CronReport\"\xa3\x01\n\x17UpdateCronReportRequest\x12X\n\ncronreport\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.CronReport\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x1a\n\x18UpdateCronReportResponse\"7\n\x14GetCronReportRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x7f\n\x15GetCronReportResponse\x12X\n\ncronreport\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.CronReport\x12\x0c\n\x04yaml\x18\x02 \x01(\t\":\n\x17\x44\x65leteCronReportRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1a\n\x18\x44\x65leteCronReportResponse\"9\n\x16PauseCronReportRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x19\n\x17PauseCronReportResponse\":\n\x17ResumeCronReportRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1a\n\x18ResumeCronReportResponse\"p\n\x14RunCronReportRequest\x12X\n\ncronreport\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.CronReport\"\x17\n\x15RunCronReportResponse2\xc4\x0e\n\x11\x43ronReportService\x12\xd3\x01\n\x0fListCronReports\x12L.github.com.metaprov.modelaapi.services.cronreport.v1.ListCronReportsRequest\x1aM.github.com.metaprov.modelaapi.services.cronreport.v1.ListCronReportsResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/v1/cronreports/{namespace}\x12\xcd\x01\n\x10\x43reateCronReport\x12M.github.com.metaprov.modelaapi.services.cronreport.v1.CreateCronReportRequest\x1aN.github.com.metaprov.modelaapi.services.cronreport.v1.CreateCronReportResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/v1/cronreports:\x01*\x12\xd4\x01\n\rGetCronReport\x12J.github.com.metaprov.modelaapi.services.cronreport.v1.GetCronReportRequest\x1aK.github.com.metaprov.modelaapi.services.cronreport.v1.GetCronReportResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/v1/cronreports/{namespace}/{name}\x12\x88\x02\n\x10UpdateCronReport\x12M.github.com.metaprov.modelaapi.services.cronreport.v1.UpdateCronReportRequest\x1aN.github.com.metaprov.modelaapi.services.cronreport.v1.UpdateCronReportResponse\"U\x82\xd3\xe4\x93\x02O\x1aJ/v1/cronreports/{cronreport.metadata.namespace}/{cronreport.metadata.name}:\x01*\x12\xdd\x01\n\x10\x44\x65leteCronReport\x12M.github.com.metaprov.modelaapi.services.cronreport.v1.DeleteCronReportRequest\x1aN.github.com.metaprov.modelaapi.services.cronreport.v1.DeleteCronReportResponse\"*\x82\xd3\xe4\x93\x02$*\"/v1/cronreports/{namespace}/{name}\x12\xfc\x01\n\tRunReport\x12J.github.com.metaprov.modelaapi.services.cronreport.v1.RunCronReportRequest\x1aK.github.com.metaprov.modelaapi.services.cronreport.v1.RunCronReportResponse\"V\x82\xd3\xe4\x93\x02P\"N/v1/cronreports/{cronreport.metadata.namespace}/{cronreport.metadata.name}:run\x12\xe0\x01\n\x0fPauseCronReport\x12L.github.com.metaprov.modelaapi.services.cronreport.v1.PauseCronReportRequest\x1aM.github.com.metaprov.modelaapi.services.cronreport.v1.PauseCronReportResponse\"0\x82\xd3\xe4\x93\x02*\"(/v1/cronreports/{namespace}/{name}:pause\x12\xe4\x01\n\x10ResumeCronReport\x12M.github.com.metaprov.modelaapi.services.cronreport.v1.ResumeCronReportRequest\x1aN.github.com.metaprov.modelaapi.services.cronreport.v1.ResumeCronReportResponse\"1\x82\xd3\xe4\x93\x02+\")/v1/cronreports/{namespace}/{name}:resumeB6Z4github.com/metaprov/modelaapi/services/cronreport/v1b\x06proto3')



_LISTCRONREPORTSREQUEST = DESCRIPTOR.message_types_by_name['ListCronReportsRequest']
_LISTCRONREPORTSREQUEST_LABELSENTRY = _LISTCRONREPORTSREQUEST.nested_types_by_name['LabelsEntry']
_LISTCRONREPORTSRESPONSE = DESCRIPTOR.message_types_by_name['ListCronReportsResponse']
_CREATECRONREPORTRESPONSE = DESCRIPTOR.message_types_by_name['CreateCronReportResponse']
_CREATECRONREPORTREQUEST = DESCRIPTOR.message_types_by_name['CreateCronReportRequest']
_UPDATECRONREPORTREQUEST = DESCRIPTOR.message_types_by_name['UpdateCronReportRequest']
_UPDATECRONREPORTRESPONSE = DESCRIPTOR.message_types_by_name['UpdateCronReportResponse']
_GETCRONREPORTREQUEST = DESCRIPTOR.message_types_by_name['GetCronReportRequest']
_GETCRONREPORTRESPONSE = DESCRIPTOR.message_types_by_name['GetCronReportResponse']
_DELETECRONREPORTREQUEST = DESCRIPTOR.message_types_by_name['DeleteCronReportRequest']
_DELETECRONREPORTRESPONSE = DESCRIPTOR.message_types_by_name['DeleteCronReportResponse']
_PAUSECRONREPORTREQUEST = DESCRIPTOR.message_types_by_name['PauseCronReportRequest']
_PAUSECRONREPORTRESPONSE = DESCRIPTOR.message_types_by_name['PauseCronReportResponse']
_RESUMECRONREPORTREQUEST = DESCRIPTOR.message_types_by_name['ResumeCronReportRequest']
_RESUMECRONREPORTRESPONSE = DESCRIPTOR.message_types_by_name['ResumeCronReportResponse']
_RUNCRONREPORTREQUEST = DESCRIPTOR.message_types_by_name['RunCronReportRequest']
_RUNCRONREPORTRESPONSE = DESCRIPTOR.message_types_by_name['RunCronReportResponse']
ListCronReportsRequest = _reflection.GeneratedProtocolMessageType('ListCronReportsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTCRONREPORTSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.cronreport.v1.cronreport_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronreport.v1.ListCronReportsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTCRONREPORTSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronreport.v1.cronreport_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronreport.v1.ListCronReportsRequest)
  })
_sym_db.RegisterMessage(ListCronReportsRequest)
_sym_db.RegisterMessage(ListCronReportsRequest.LabelsEntry)

ListCronReportsResponse = _reflection.GeneratedProtocolMessageType('ListCronReportsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCRONREPORTSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronreport.v1.cronreport_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronreport.v1.ListCronReportsResponse)
  })
_sym_db.RegisterMessage(ListCronReportsResponse)

CreateCronReportResponse = _reflection.GeneratedProtocolMessageType('CreateCronReportResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATECRONREPORTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronreport.v1.cronreport_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronreport.v1.CreateCronReportResponse)
  })
_sym_db.RegisterMessage(CreateCronReportResponse)

CreateCronReportRequest = _reflection.GeneratedProtocolMessageType('CreateCronReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATECRONREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronreport.v1.cronreport_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronreport.v1.CreateCronReportRequest)
  })
_sym_db.RegisterMessage(CreateCronReportRequest)

UpdateCronReportRequest = _reflection.GeneratedProtocolMessageType('UpdateCronReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECRONREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronreport.v1.cronreport_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronreport.v1.UpdateCronReportRequest)
  })
_sym_db.RegisterMessage(UpdateCronReportRequest)

UpdateCronReportResponse = _reflection.GeneratedProtocolMessageType('UpdateCronReportResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECRONREPORTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronreport.v1.cronreport_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronreport.v1.UpdateCronReportResponse)
  })
_sym_db.RegisterMessage(UpdateCronReportResponse)

GetCronReportRequest = _reflection.GeneratedProtocolMessageType('GetCronReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCRONREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronreport.v1.cronreport_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronreport.v1.GetCronReportRequest)
  })
_sym_db.RegisterMessage(GetCronReportRequest)

GetCronReportResponse = _reflection.GeneratedProtocolMessageType('GetCronReportResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCRONREPORTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronreport.v1.cronreport_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronreport.v1.GetCronReportResponse)
  })
_sym_db.RegisterMessage(GetCronReportResponse)

DeleteCronReportRequest = _reflection.GeneratedProtocolMessageType('DeleteCronReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETECRONREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronreport.v1.cronreport_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronreport.v1.DeleteCronReportRequest)
  })
_sym_db.RegisterMessage(DeleteCronReportRequest)

DeleteCronReportResponse = _reflection.GeneratedProtocolMessageType('DeleteCronReportResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETECRONREPORTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronreport.v1.cronreport_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronreport.v1.DeleteCronReportResponse)
  })
_sym_db.RegisterMessage(DeleteCronReportResponse)

PauseCronReportRequest = _reflection.GeneratedProtocolMessageType('PauseCronReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _PAUSECRONREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronreport.v1.cronreport_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronreport.v1.PauseCronReportRequest)
  })
_sym_db.RegisterMessage(PauseCronReportRequest)

PauseCronReportResponse = _reflection.GeneratedProtocolMessageType('PauseCronReportResponse', (_message.Message,), {
  'DESCRIPTOR' : _PAUSECRONREPORTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronreport.v1.cronreport_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronreport.v1.PauseCronReportResponse)
  })
_sym_db.RegisterMessage(PauseCronReportResponse)

ResumeCronReportRequest = _reflection.GeneratedProtocolMessageType('ResumeCronReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESUMECRONREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronreport.v1.cronreport_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronreport.v1.ResumeCronReportRequest)
  })
_sym_db.RegisterMessage(ResumeCronReportRequest)

ResumeCronReportResponse = _reflection.GeneratedProtocolMessageType('ResumeCronReportResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESUMECRONREPORTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronreport.v1.cronreport_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronreport.v1.ResumeCronReportResponse)
  })
_sym_db.RegisterMessage(ResumeCronReportResponse)

RunCronReportRequest = _reflection.GeneratedProtocolMessageType('RunCronReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _RUNCRONREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronreport.v1.cronreport_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronreport.v1.RunCronReportRequest)
  })
_sym_db.RegisterMessage(RunCronReportRequest)

RunCronReportResponse = _reflection.GeneratedProtocolMessageType('RunCronReportResponse', (_message.Message,), {
  'DESCRIPTOR' : _RUNCRONREPORTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronreport.v1.cronreport_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronreport.v1.RunCronReportResponse)
  })
_sym_db.RegisterMessage(RunCronReportResponse)

_CRONREPORTSERVICE = DESCRIPTOR.services_by_name['CronReportService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z4github.com/metaprov/modelaapi/services/cronreport/v1'
  _LISTCRONREPORTSREQUEST_LABELSENTRY._options = None
  _LISTCRONREPORTSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CRONREPORTSERVICE.methods_by_name['ListCronReports']._options = None
  _CRONREPORTSERVICE.methods_by_name['ListCronReports']._serialized_options = b'\202\323\344\223\002\035\022\033/v1/cronreports/{namespace}'
  _CRONREPORTSERVICE.methods_by_name['CreateCronReport']._options = None
  _CRONREPORTSERVICE.methods_by_name['CreateCronReport']._serialized_options = b'\202\323\344\223\002\024\"\017/v1/cronreports:\001*'
  _CRONREPORTSERVICE.methods_by_name['GetCronReport']._options = None
  _CRONREPORTSERVICE.methods_by_name['GetCronReport']._serialized_options = b'\202\323\344\223\002$\022\"/v1/cronreports/{namespace}/{name}'
  _CRONREPORTSERVICE.methods_by_name['UpdateCronReport']._options = None
  _CRONREPORTSERVICE.methods_by_name['UpdateCronReport']._serialized_options = b'\202\323\344\223\002O\032J/v1/cronreports/{cronreport.metadata.namespace}/{cronreport.metadata.name}:\001*'
  _CRONREPORTSERVICE.methods_by_name['DeleteCronReport']._options = None
  _CRONREPORTSERVICE.methods_by_name['DeleteCronReport']._serialized_options = b'\202\323\344\223\002$*\"/v1/cronreports/{namespace}/{name}'
  _CRONREPORTSERVICE.methods_by_name['RunReport']._options = None
  _CRONREPORTSERVICE.methods_by_name['RunReport']._serialized_options = b'\202\323\344\223\002P\"N/v1/cronreports/{cronreport.metadata.namespace}/{cronreport.metadata.name}:run'
  _CRONREPORTSERVICE.methods_by_name['PauseCronReport']._options = None
  _CRONREPORTSERVICE.methods_by_name['PauseCronReport']._serialized_options = b'\202\323\344\223\002*\"(/v1/cronreports/{namespace}/{name}:pause'
  _CRONREPORTSERVICE.methods_by_name['ResumeCronReport']._options = None
  _CRONREPORTSERVICE.methods_by_name['ResumeCronReport']._serialized_options = b'\202\323\344\223\002+\")/v1/cronreports/{namespace}/{name}:resume'
  _LISTCRONREPORTSREQUEST._serialized_start=266
  _LISTCRONREPORTSREQUEST._serialized_end=519
  _LISTCRONREPORTSREQUEST_LABELSENTRY._serialized_start=474
  _LISTCRONREPORTSREQUEST_LABELSENTRY._serialized_end=519
  _LISTCRONREPORTSRESPONSE._serialized_start=522
  _LISTCRONREPORTSRESPONSE._serialized_end=667
  _CREATECRONREPORTRESPONSE._serialized_start=669
  _CREATECRONREPORTRESPONSE._serialized_end=695
  _CREATECRONREPORTREQUEST._serialized_start=697
  _CREATECRONREPORTREQUEST._serialized_end=812
  _UPDATECRONREPORTREQUEST._serialized_start=815
  _UPDATECRONREPORTREQUEST._serialized_end=978
  _UPDATECRONREPORTRESPONSE._serialized_start=980
  _UPDATECRONREPORTRESPONSE._serialized_end=1006
  _GETCRONREPORTREQUEST._serialized_start=1008
  _GETCRONREPORTREQUEST._serialized_end=1063
  _GETCRONREPORTRESPONSE._serialized_start=1065
  _GETCRONREPORTRESPONSE._serialized_end=1192
  _DELETECRONREPORTREQUEST._serialized_start=1194
  _DELETECRONREPORTREQUEST._serialized_end=1252
  _DELETECRONREPORTRESPONSE._serialized_start=1254
  _DELETECRONREPORTRESPONSE._serialized_end=1280
  _PAUSECRONREPORTREQUEST._serialized_start=1282
  _PAUSECRONREPORTREQUEST._serialized_end=1339
  _PAUSECRONREPORTRESPONSE._serialized_start=1341
  _PAUSECRONREPORTRESPONSE._serialized_end=1366
  _RESUMECRONREPORTREQUEST._serialized_start=1368
  _RESUMECRONREPORTREQUEST._serialized_end=1426
  _RESUMECRONREPORTRESPONSE._serialized_start=1428
  _RESUMECRONREPORTRESPONSE._serialized_end=1454
  _RUNCRONREPORTREQUEST._serialized_start=1456
  _RUNCRONREPORTREQUEST._serialized_end=1568
  _RUNCRONREPORTRESPONSE._serialized_start=1570
  _RUNCRONREPORTRESPONSE._serialized_end=1593
  _CRONREPORTSERVICE._serialized_start=1596
  _CRONREPORTSERVICE._serialized_end=3456
# @@protoc_insertion_point(module_scope)
