# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/curtain/v1/curtain.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?github.com/metaprov/modelaapi/services/curtain/v1/curtain.proto\x12\x31github.com.metaprov.modelaapi.services.curtain.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1aIgithub.com/metaprov/modelaapi/pkg/apis/inference/v1alpha1/generated.proto\"\xf4\x01\n\x13ListCurtainsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x62\n\x06labels\x18\x02 \x03(\x0b\x32R.github.com.metaprov.modelaapi.services.curtain.v1.ListCurtainsRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x89\x01\n\x14ListCurtainsResponse\x12X\n\x08\x63urtains\x18\x01 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.CurtainList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x17\n\x15\x43reateCurtainResponse\"k\n\x14\x43reateCurtainRequest\x12S\n\x07\x63urtain\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Curtain\"\x9b\x01\n\x14UpdateCurtainRequest\x12S\n\x07\x63urtain\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Curtain\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x17\n\x15UpdateCurtainResponse\"4\n\x11GetCurtainRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"w\n\x12GetCurtainResponse\x12S\n\x07\x63urtain\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Curtain\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"7\n\x14\x44\x65leteCurtainRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x17\n\x15\x44\x65leteCurtainResponse2\x98\x08\n\x0e\x43urtainService\x12\xc1\x01\n\x0cListCurtains\x12\x46.github.com.metaprov.modelaapi.services.curtain.v1.ListCurtainsRequest\x1aG.github.com.metaprov.modelaapi.services.curtain.v1.ListCurtainsResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/v1/curtains/{namespace}\x12\xbb\x01\n\rCreateCurtain\x12G.github.com.metaprov.modelaapi.services.curtain.v1.CreateCurtainRequest\x1aH.github.com.metaprov.modelaapi.services.curtain.v1.CreateCurtainResponse\"\x17\x82\xd3\xe4\x93\x02\x11\"\x0c/v1/curtains:\x01*\x12\xc2\x01\n\nGetCurtain\x12\x44.github.com.metaprov.modelaapi.services.curtain.v1.GetCurtainRequest\x1a\x45.github.com.metaprov.modelaapi.services.curtain.v1.GetCurtainResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/v1/curtains/{namespace}/{name}\x12\xf0\x01\n\rUpdateCurtain\x12G.github.com.metaprov.modelaapi.services.curtain.v1.UpdateCurtainRequest\x1aH.github.com.metaprov.modelaapi.services.curtain.v1.UpdateCurtainResponse\"L\x82\xd3\xe4\x93\x02\x46\x1a\x41/v1/curtains/{curtain.metadata.namespace}/{curtain.metadata.name}:\x01*\x12\xcb\x01\n\rDeleteCurtain\x12G.github.com.metaprov.modelaapi.services.curtain.v1.DeleteCurtainRequest\x1aH.github.com.metaprov.modelaapi.services.curtain.v1.DeleteCurtainResponse\"\'\x82\xd3\xe4\x93\x02!*\x1f/v1/curtains/{namespace}/{name}B3Z1github.com/metaprov/modelaapi/services/curtain/v1b\x06proto3')



_LISTCURTAINSREQUEST = DESCRIPTOR.message_types_by_name['ListCurtainsRequest']
_LISTCURTAINSREQUEST_LABELSENTRY = _LISTCURTAINSREQUEST.nested_types_by_name['LabelsEntry']
_LISTCURTAINSRESPONSE = DESCRIPTOR.message_types_by_name['ListCurtainsResponse']
_CREATECURTAINRESPONSE = DESCRIPTOR.message_types_by_name['CreateCurtainResponse']
_CREATECURTAINREQUEST = DESCRIPTOR.message_types_by_name['CreateCurtainRequest']
_UPDATECURTAINREQUEST = DESCRIPTOR.message_types_by_name['UpdateCurtainRequest']
_UPDATECURTAINRESPONSE = DESCRIPTOR.message_types_by_name['UpdateCurtainResponse']
_GETCURTAINREQUEST = DESCRIPTOR.message_types_by_name['GetCurtainRequest']
_GETCURTAINRESPONSE = DESCRIPTOR.message_types_by_name['GetCurtainResponse']
_DELETECURTAINREQUEST = DESCRIPTOR.message_types_by_name['DeleteCurtainRequest']
_DELETECURTAINRESPONSE = DESCRIPTOR.message_types_by_name['DeleteCurtainResponse']
ListCurtainsRequest = _reflection.GeneratedProtocolMessageType('ListCurtainsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTCURTAINSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.curtain.v1.curtain_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.curtain.v1.ListCurtainsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTCURTAINSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.curtain.v1.curtain_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.curtain.v1.ListCurtainsRequest)
  })
_sym_db.RegisterMessage(ListCurtainsRequest)
_sym_db.RegisterMessage(ListCurtainsRequest.LabelsEntry)

ListCurtainsResponse = _reflection.GeneratedProtocolMessageType('ListCurtainsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCURTAINSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.curtain.v1.curtain_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.curtain.v1.ListCurtainsResponse)
  })
_sym_db.RegisterMessage(ListCurtainsResponse)

CreateCurtainResponse = _reflection.GeneratedProtocolMessageType('CreateCurtainResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATECURTAINRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.curtain.v1.curtain_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.curtain.v1.CreateCurtainResponse)
  })
_sym_db.RegisterMessage(CreateCurtainResponse)

CreateCurtainRequest = _reflection.GeneratedProtocolMessageType('CreateCurtainRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATECURTAINREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.curtain.v1.curtain_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.curtain.v1.CreateCurtainRequest)
  })
_sym_db.RegisterMessage(CreateCurtainRequest)

UpdateCurtainRequest = _reflection.GeneratedProtocolMessageType('UpdateCurtainRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECURTAINREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.curtain.v1.curtain_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.curtain.v1.UpdateCurtainRequest)
  })
_sym_db.RegisterMessage(UpdateCurtainRequest)

UpdateCurtainResponse = _reflection.GeneratedProtocolMessageType('UpdateCurtainResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECURTAINRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.curtain.v1.curtain_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.curtain.v1.UpdateCurtainResponse)
  })
_sym_db.RegisterMessage(UpdateCurtainResponse)

GetCurtainRequest = _reflection.GeneratedProtocolMessageType('GetCurtainRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCURTAINREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.curtain.v1.curtain_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.curtain.v1.GetCurtainRequest)
  })
_sym_db.RegisterMessage(GetCurtainRequest)

GetCurtainResponse = _reflection.GeneratedProtocolMessageType('GetCurtainResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCURTAINRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.curtain.v1.curtain_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.curtain.v1.GetCurtainResponse)
  })
_sym_db.RegisterMessage(GetCurtainResponse)

DeleteCurtainRequest = _reflection.GeneratedProtocolMessageType('DeleteCurtainRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETECURTAINREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.curtain.v1.curtain_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.curtain.v1.DeleteCurtainRequest)
  })
_sym_db.RegisterMessage(DeleteCurtainRequest)

DeleteCurtainResponse = _reflection.GeneratedProtocolMessageType('DeleteCurtainResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETECURTAINRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.curtain.v1.curtain_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.curtain.v1.DeleteCurtainResponse)
  })
_sym_db.RegisterMessage(DeleteCurtainResponse)

_CURTAINSERVICE = DESCRIPTOR.services_by_name['CurtainService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/metaprov/modelaapi/services/curtain/v1'
  _LISTCURTAINSREQUEST_LABELSENTRY._options = None
  _LISTCURTAINSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CURTAINSERVICE.methods_by_name['ListCurtains']._options = None
  _CURTAINSERVICE.methods_by_name['ListCurtains']._serialized_options = b'\202\323\344\223\002\032\022\030/v1/curtains/{namespace}'
  _CURTAINSERVICE.methods_by_name['CreateCurtain']._options = None
  _CURTAINSERVICE.methods_by_name['CreateCurtain']._serialized_options = b'\202\323\344\223\002\021\"\014/v1/curtains:\001*'
  _CURTAINSERVICE.methods_by_name['GetCurtain']._options = None
  _CURTAINSERVICE.methods_by_name['GetCurtain']._serialized_options = b'\202\323\344\223\002!\022\037/v1/curtains/{namespace}/{name}'
  _CURTAINSERVICE.methods_by_name['UpdateCurtain']._options = None
  _CURTAINSERVICE.methods_by_name['UpdateCurtain']._serialized_options = b'\202\323\344\223\002F\032A/v1/curtains/{curtain.metadata.namespace}/{curtain.metadata.name}:\001*'
  _CURTAINSERVICE.methods_by_name['DeleteCurtain']._options = None
  _CURTAINSERVICE.methods_by_name['DeleteCurtain']._serialized_options = b'\202\323\344\223\002!*\037/v1/curtains/{namespace}/{name}'
  _LISTCURTAINSREQUEST._serialized_start=258
  _LISTCURTAINSREQUEST._serialized_end=502
  _LISTCURTAINSREQUEST_LABELSENTRY._serialized_start=457
  _LISTCURTAINSREQUEST_LABELSENTRY._serialized_end=502
  _LISTCURTAINSRESPONSE._serialized_start=505
  _LISTCURTAINSRESPONSE._serialized_end=642
  _CREATECURTAINRESPONSE._serialized_start=644
  _CREATECURTAINRESPONSE._serialized_end=667
  _CREATECURTAINREQUEST._serialized_start=669
  _CREATECURTAINREQUEST._serialized_end=776
  _UPDATECURTAINREQUEST._serialized_start=779
  _UPDATECURTAINREQUEST._serialized_end=934
  _UPDATECURTAINRESPONSE._serialized_start=936
  _UPDATECURTAINRESPONSE._serialized_end=959
  _GETCURTAINREQUEST._serialized_start=961
  _GETCURTAINREQUEST._serialized_end=1013
  _GETCURTAINRESPONSE._serialized_start=1015
  _GETCURTAINRESPONSE._serialized_end=1134
  _DELETECURTAINREQUEST._serialized_start=1136
  _DELETECURTAINREQUEST._serialized_end=1191
  _DELETECURTAINRESPONSE._serialized_start=1193
  _DELETECURTAINRESPONSE._serialized_end=1216
  _CURTAINSERVICE._serialized_start=1219
  _CURTAINSERVICE._serialized_end=2267
# @@protoc_insertion_point(module_scope)
