# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.meeting.v1 import meeting_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2


class MeetingServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListMeetings = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.meeting.v1.MeetingService/ListMeetings',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.ListMeetingsRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.ListMeetingsResponse.FromString,
                )
        self.CreateMeeting = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.meeting.v1.MeetingService/CreateMeeting',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.CreateMeetingRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.CreateMeetingResponse.FromString,
                )
        self.GetMeeting = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.meeting.v1.MeetingService/GetMeeting',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.GetMeetingRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.GetMeetingResponse.FromString,
                )
        self.UpdateMeeting = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.meeting.v1.MeetingService/UpdateMeeting',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.UpdateMeetingRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.UpdateMeetingResponse.FromString,
                )
        self.DeleteMeeting = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.meeting.v1.MeetingService/DeleteMeeting',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.DeleteMeetingRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.DeleteMeetingResponse.FromString,
                )


class MeetingServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListMeetings(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateMeeting(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMeeting(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateMeeting(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteMeeting(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MeetingServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListMeetings': grpc.unary_unary_rpc_method_handler(
                    servicer.ListMeetings,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.ListMeetingsRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.ListMeetingsResponse.SerializeToString,
            ),
            'CreateMeeting': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateMeeting,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.CreateMeetingRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.CreateMeetingResponse.SerializeToString,
            ),
            'GetMeeting': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMeeting,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.GetMeetingRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.GetMeetingResponse.SerializeToString,
            ),
            'UpdateMeeting': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateMeeting,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.UpdateMeetingRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.UpdateMeetingResponse.SerializeToString,
            ),
            'DeleteMeeting': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteMeeting,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.DeleteMeetingRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.DeleteMeetingResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.meeting.v1.MeetingService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class MeetingService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListMeetings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.meeting.v1.MeetingService/ListMeetings',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.ListMeetingsRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.ListMeetingsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateMeeting(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.meeting.v1.MeetingService/CreateMeeting',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.CreateMeetingRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.CreateMeetingResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetMeeting(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.meeting.v1.MeetingService/GetMeeting',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.GetMeetingRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.GetMeetingResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateMeeting(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.meeting.v1.MeetingService/UpdateMeeting',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.UpdateMeetingRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.UpdateMeetingResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteMeeting(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.meeting.v1.MeetingService/DeleteMeeting',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.DeleteMeetingRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.DeleteMeetingResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
