# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.recipe.v1 import recipe_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2


class RecipeServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListRecipes = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.recipe.v1.RecipeService/ListRecipes',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.ListRecipesRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.ListRecipesResponse.FromString,
                )
        self.CreateRecipe = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.recipe.v1.RecipeService/CreateRecipe',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.CreateRecipeRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.CreateRecipeResponse.FromString,
                )
        self.GetRecipe = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.recipe.v1.RecipeService/GetRecipe',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.GetRecipeRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.GetRecipeResponse.FromString,
                )
        self.RunRecipe = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.recipe.v1.RecipeService/RunRecipe',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.RunRecipeRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.RunRecipeResponse.FromString,
                )
        self.ProfileRecipe = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.recipe.v1.RecipeService/ProfileRecipe',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.ProfileRecipeRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.ProfileRecipeResponse.FromString,
                )
        self.UpdateRecipe = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.recipe.v1.RecipeService/UpdateRecipe',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.UpdateRecipeRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.UpdateRecipeResponse.FromString,
                )
        self.DeleteRecipe = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.recipe.v1.RecipeService/DeleteRecipe',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.DeleteRecipeRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.DeleteRecipeResponse.FromString,
                )


class RecipeServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListRecipes(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateRecipe(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRecipe(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RunRecipe(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ProfileRecipe(self, request, context):
        """profile the recipe based on the sample
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateRecipe(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteRecipe(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_RecipeServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListRecipes': grpc.unary_unary_rpc_method_handler(
                    servicer.ListRecipes,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.ListRecipesRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.ListRecipesResponse.SerializeToString,
            ),
            'CreateRecipe': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateRecipe,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.CreateRecipeRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.CreateRecipeResponse.SerializeToString,
            ),
            'GetRecipe': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRecipe,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.GetRecipeRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.GetRecipeResponse.SerializeToString,
            ),
            'RunRecipe': grpc.unary_unary_rpc_method_handler(
                    servicer.RunRecipe,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.RunRecipeRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.RunRecipeResponse.SerializeToString,
            ),
            'ProfileRecipe': grpc.unary_unary_rpc_method_handler(
                    servicer.ProfileRecipe,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.ProfileRecipeRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.ProfileRecipeResponse.SerializeToString,
            ),
            'UpdateRecipe': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateRecipe,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.UpdateRecipeRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.UpdateRecipeResponse.SerializeToString,
            ),
            'DeleteRecipe': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteRecipe,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.DeleteRecipeRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.DeleteRecipeResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.recipe.v1.RecipeService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class RecipeService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListRecipes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.recipe.v1.RecipeService/ListRecipes',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.ListRecipesRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.ListRecipesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateRecipe(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.recipe.v1.RecipeService/CreateRecipe',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.CreateRecipeRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.CreateRecipeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRecipe(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.recipe.v1.RecipeService/GetRecipe',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.GetRecipeRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.GetRecipeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RunRecipe(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.recipe.v1.RecipeService/RunRecipe',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.RunRecipeRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.RunRecipeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ProfileRecipe(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.recipe.v1.RecipeService/ProfileRecipe',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.ProfileRecipeRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.ProfileRecipeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateRecipe(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.recipe.v1.RecipeService/UpdateRecipe',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.UpdateRecipeRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.UpdateRecipeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteRecipe(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.recipe.v1.RecipeService/DeleteRecipe',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.DeleteRecipeRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.DeleteRecipeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
