# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/labelingpipelinerun/v1/labelingpipelinerun.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nWgithub.com/metaprov/modelaapi/services/labelingpipelinerun/v1/labelingpipelinerun.proto\x12=github.com.metaprov.modelaapi.services.labelingpipelinerun.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\"\x96\x02\n\x1eListLabelingPipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12y\n\x06labels\x18\x02 \x03(\x0b\x32i.github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.ListLabelingPipelineRunRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa7\x01\n\x1fListLabelingPipelineRunResponse\x12k\n\x14labelingpipelineruns\x18\x01 \x01(\x0b\x32M.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipelineRunList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x8a\x01\n CreateLabelingPipelineRunRequest\x12\x66\n\x13labelingpipelinerun\x18\x01 \x01(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipelineRun\"#\n!CreateLabelingPipelineRunResponse\"\xba\x01\n UpdateLabelingPipelineRunRequest\x12\x66\n\x13labelingpipelinerun\x18\x01 \x01(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipelineRun\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"#\n!UpdateLabelingPipelineRunResponse\"@\n\x1dGetLabelingPipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x96\x01\n\x1eGetLabelingPipelineRunResponse\x12\x66\n\x13labelingpipelinerun\x18\x01 \x01(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipelineRun\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"C\n DeleteLabelingPipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"#\n!DeleteLabelingPipelineRunResponse2\xa2\x0b\n\x1aLabelingPipelineRunService\x12\x87\x02\n\x18ListLabelingPipelineRuns\x12].github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.ListLabelingPipelineRunRequest\x1a^.github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.ListLabelingPipelineRunResponse\",\x82\xd3\xe4\x93\x02&\x12$/v1/labelingpipelineruns/{namespace}\x12\x83\x02\n\x19\x43reateLabelingPipelineRun\x12_.github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.CreateLabelingPipelineRunRequest\x1a`.github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.CreateLabelingPipelineRunResponse\"#\x82\xd3\xe4\x93\x02\x1d\"\x18/v1/labelingpipelineruns:\x01*\x12\x8a\x02\n\x16GetLabelingPipelineRun\x12\\.github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.GetLabelingPipelineRunRequest\x1a].github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.GetLabelingPipelineRunResponse\"3\x82\xd3\xe4\x93\x02-\x12+/v1/labelingpipelineruns/{namespace}/{name}\x12\xd0\x02\n\x19UpdateLabelingPipelineRun\x12_.github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.UpdateLabelingPipelineRunRequest\x1a`.github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.UpdateLabelingPipelineRunResponse\"p\x82\xd3\xe4\x93\x02j\x1a\x65/v1/labelingpipelineruns/{labelingpipelinerun.metadata.namespace}/{labelingpipelinerun.metadata.name}:\x01*\x12\x93\x02\n\x19\x44\x65leteLabelingPipelineRun\x12_.github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.DeleteLabelingPipelineRunRequest\x1a`.github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.DeleteLabelingPipelineRunResponse\"3\x82\xd3\xe4\x93\x02-*+/v1/labelingpipelineruns/{namespace}/{name}B?Z=github.com/metaprov/modelaapi/services/labelingpipelinerun/v1b\x06proto3')



_LISTLABELINGPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['ListLabelingPipelineRunRequest']
_LISTLABELINGPIPELINERUNREQUEST_LABELSENTRY = _LISTLABELINGPIPELINERUNREQUEST.nested_types_by_name['LabelsEntry']
_LISTLABELINGPIPELINERUNRESPONSE = DESCRIPTOR.message_types_by_name['ListLabelingPipelineRunResponse']
_CREATELABELINGPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['CreateLabelingPipelineRunRequest']
_CREATELABELINGPIPELINERUNRESPONSE = DESCRIPTOR.message_types_by_name['CreateLabelingPipelineRunResponse']
_UPDATELABELINGPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['UpdateLabelingPipelineRunRequest']
_UPDATELABELINGPIPELINERUNRESPONSE = DESCRIPTOR.message_types_by_name['UpdateLabelingPipelineRunResponse']
_GETLABELINGPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['GetLabelingPipelineRunRequest']
_GETLABELINGPIPELINERUNRESPONSE = DESCRIPTOR.message_types_by_name['GetLabelingPipelineRunResponse']
_DELETELABELINGPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['DeleteLabelingPipelineRunRequest']
_DELETELABELINGPIPELINERUNRESPONSE = DESCRIPTOR.message_types_by_name['DeleteLabelingPipelineRunResponse']
ListLabelingPipelineRunRequest = _reflection.GeneratedProtocolMessageType('ListLabelingPipelineRunRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTLABELINGPIPELINERUNREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.labelingpipelinerun_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.ListLabelingPipelineRunRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTLABELINGPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.labelingpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.ListLabelingPipelineRunRequest)
  })
_sym_db.RegisterMessage(ListLabelingPipelineRunRequest)
_sym_db.RegisterMessage(ListLabelingPipelineRunRequest.LabelsEntry)

ListLabelingPipelineRunResponse = _reflection.GeneratedProtocolMessageType('ListLabelingPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTLABELINGPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.labelingpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.ListLabelingPipelineRunResponse)
  })
_sym_db.RegisterMessage(ListLabelingPipelineRunResponse)

CreateLabelingPipelineRunRequest = _reflection.GeneratedProtocolMessageType('CreateLabelingPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATELABELINGPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.labelingpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.CreateLabelingPipelineRunRequest)
  })
_sym_db.RegisterMessage(CreateLabelingPipelineRunRequest)

CreateLabelingPipelineRunResponse = _reflection.GeneratedProtocolMessageType('CreateLabelingPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATELABELINGPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.labelingpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.CreateLabelingPipelineRunResponse)
  })
_sym_db.RegisterMessage(CreateLabelingPipelineRunResponse)

UpdateLabelingPipelineRunRequest = _reflection.GeneratedProtocolMessageType('UpdateLabelingPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATELABELINGPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.labelingpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.UpdateLabelingPipelineRunRequest)
  })
_sym_db.RegisterMessage(UpdateLabelingPipelineRunRequest)

UpdateLabelingPipelineRunResponse = _reflection.GeneratedProtocolMessageType('UpdateLabelingPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATELABELINGPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.labelingpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.UpdateLabelingPipelineRunResponse)
  })
_sym_db.RegisterMessage(UpdateLabelingPipelineRunResponse)

GetLabelingPipelineRunRequest = _reflection.GeneratedProtocolMessageType('GetLabelingPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLABELINGPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.labelingpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.GetLabelingPipelineRunRequest)
  })
_sym_db.RegisterMessage(GetLabelingPipelineRunRequest)

GetLabelingPipelineRunResponse = _reflection.GeneratedProtocolMessageType('GetLabelingPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETLABELINGPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.labelingpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.GetLabelingPipelineRunResponse)
  })
_sym_db.RegisterMessage(GetLabelingPipelineRunResponse)

DeleteLabelingPipelineRunRequest = _reflection.GeneratedProtocolMessageType('DeleteLabelingPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETELABELINGPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.labelingpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.DeleteLabelingPipelineRunRequest)
  })
_sym_db.RegisterMessage(DeleteLabelingPipelineRunRequest)

DeleteLabelingPipelineRunResponse = _reflection.GeneratedProtocolMessageType('DeleteLabelingPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETELABELINGPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.labelingpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.DeleteLabelingPipelineRunResponse)
  })
_sym_db.RegisterMessage(DeleteLabelingPipelineRunResponse)

_LABELINGPIPELINERUNSERVICE = DESCRIPTOR.services_by_name['LabelingPipelineRunService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z=github.com/metaprov/modelaapi/services/labelingpipelinerun/v1'
  _LISTLABELINGPIPELINERUNREQUEST_LABELSENTRY._options = None
  _LISTLABELINGPIPELINERUNREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _LABELINGPIPELINERUNSERVICE.methods_by_name['ListLabelingPipelineRuns']._options = None
  _LABELINGPIPELINERUNSERVICE.methods_by_name['ListLabelingPipelineRuns']._serialized_options = b'\202\323\344\223\002&\022$/v1/labelingpipelineruns/{namespace}'
  _LABELINGPIPELINERUNSERVICE.methods_by_name['CreateLabelingPipelineRun']._options = None
  _LABELINGPIPELINERUNSERVICE.methods_by_name['CreateLabelingPipelineRun']._serialized_options = b'\202\323\344\223\002\035\"\030/v1/labelingpipelineruns:\001*'
  _LABELINGPIPELINERUNSERVICE.methods_by_name['GetLabelingPipelineRun']._options = None
  _LABELINGPIPELINERUNSERVICE.methods_by_name['GetLabelingPipelineRun']._serialized_options = b'\202\323\344\223\002-\022+/v1/labelingpipelineruns/{namespace}/{name}'
  _LABELINGPIPELINERUNSERVICE.methods_by_name['UpdateLabelingPipelineRun']._options = None
  _LABELINGPIPELINERUNSERVICE.methods_by_name['UpdateLabelingPipelineRun']._serialized_options = b'\202\323\344\223\002j\032e/v1/labelingpipelineruns/{labelingpipelinerun.metadata.namespace}/{labelingpipelinerun.metadata.name}:\001*'
  _LABELINGPIPELINERUNSERVICE.methods_by_name['DeleteLabelingPipelineRun']._options = None
  _LABELINGPIPELINERUNSERVICE.methods_by_name['DeleteLabelingPipelineRun']._serialized_options = b'\202\323\344\223\002-*+/v1/labelingpipelineruns/{namespace}/{name}'
  _LISTLABELINGPIPELINERUNREQUEST._serialized_start=289
  _LISTLABELINGPIPELINERUNREQUEST._serialized_end=567
  _LISTLABELINGPIPELINERUNREQUEST_LABELSENTRY._serialized_start=522
  _LISTLABELINGPIPELINERUNREQUEST_LABELSENTRY._serialized_end=567
  _LISTLABELINGPIPELINERUNRESPONSE._serialized_start=570
  _LISTLABELINGPIPELINERUNRESPONSE._serialized_end=737
  _CREATELABELINGPIPELINERUNREQUEST._serialized_start=740
  _CREATELABELINGPIPELINERUNREQUEST._serialized_end=878
  _CREATELABELINGPIPELINERUNRESPONSE._serialized_start=880
  _CREATELABELINGPIPELINERUNRESPONSE._serialized_end=915
  _UPDATELABELINGPIPELINERUNREQUEST._serialized_start=918
  _UPDATELABELINGPIPELINERUNREQUEST._serialized_end=1104
  _UPDATELABELINGPIPELINERUNRESPONSE._serialized_start=1106
  _UPDATELABELINGPIPELINERUNRESPONSE._serialized_end=1141
  _GETLABELINGPIPELINERUNREQUEST._serialized_start=1143
  _GETLABELINGPIPELINERUNREQUEST._serialized_end=1207
  _GETLABELINGPIPELINERUNRESPONSE._serialized_start=1210
  _GETLABELINGPIPELINERUNRESPONSE._serialized_end=1360
  _DELETELABELINGPIPELINERUNREQUEST._serialized_start=1362
  _DELETELABELINGPIPELINERUNREQUEST._serialized_end=1429
  _DELETELABELINGPIPELINERUNRESPONSE._serialized_start=1431
  _DELETELABELINGPIPELINERUNRESPONSE._serialized_end=1466
  _LABELINGPIPELINERUNSERVICE._serialized_start=1469
  _LABELINGPIPELINERUNSERVICE._serialized_end=2911
# @@protoc_insertion_point(module_scope)
