# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/datasource/v1/datasource.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.services.common.v1 import common_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEgithub.com/metaprov/modelaapi/services/datasource/v1/datasource.proto\x12\x34github.com.metaprov.modelaapi.services.datasource.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\x1a=github.com/metaprov/modelaapi/services/common/v1/common.proto\"\xfb\x01\n\x15ListDataSourceRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12g\n\x06labels\x18\x02 \x03(\x0b\x32W.github.com.metaprov.modelaapi.services.datasource.v1.ListDataSourceRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8c\x01\n\x16ListDataSourceResponse\x12Y\n\x0b\x64\x61tasources\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSourceList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"7\n\x14GetDataSourceRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"{\n\x15GetDataSourceResponse\x12T\n\ndatasource\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"\x9f\x01\n\x17UpdateDataSourceRequest\x12T\n\ndatasource\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x1a\n\x18UpdateDataSourceResponse\"o\n\x17\x43reateDataSourceRequest\x12T\n\ndatasource\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\"\x1a\n\x18\x43reateDataSourceResponse\":\n\x17\x44\x65leteDataSourceRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1a\n\x18\x44\x65leteDataSourceResponse\"\xe1\x01\n\x12InferSchemaRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12T\n\ndatasource\x18\x03 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12T\n\x08location\x18\x04 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataLocation\"g\n\x13InferSchemaResponse\x12P\n\x07\x63olumns\x18\x01 \x03(\x0b\x32?.github.com.metaprov.modelaapi.services.common.v1.ColumnProfile\"\xd4\x01\n\x13GetTableViewRequest\x12\x0e\n\x06tenant\x18\x01 \x01(\t\x12W\n\x0c\x66latfilespec\x18\x02 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.CsvFileSpec\x12T\n\x08location\x18\x03 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataLocation\"b\n\x14GetTableViewResponse\x12J\n\x05table\x18\x01 \x01(\x0b\x32;.github.com.metaprov.modelaapi.services.common.v1.TableView2\xfa\x0b\n\x11\x44\x61taSourceService\x12\xd1\x01\n\x0fListDataSources\x12K.github.com.metaprov.modelaapi.services.datasource.v1.ListDataSourceRequest\x1aL.github.com.metaprov.modelaapi.services.datasource.v1.ListDataSourceResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/v1/datasources/{namespace}\x12\xcd\x01\n\x10\x43reateDataSource\x12M.github.com.metaprov.modelaapi.services.datasource.v1.CreateDataSourceRequest\x1aN.github.com.metaprov.modelaapi.services.datasource.v1.CreateDataSourceResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/v1/datasources:\x01*\x12\xd4\x01\n\rGetDataSource\x12J.github.com.metaprov.modelaapi.services.datasource.v1.GetDataSourceRequest\x1aK.github.com.metaprov.modelaapi.services.datasource.v1.GetDataSourceResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/v1/datasources/{namespace}/{name}\x12\x88\x02\n\x10UpdateDataSource\x12M.github.com.metaprov.modelaapi.services.datasource.v1.UpdateDataSourceRequest\x1aN.github.com.metaprov.modelaapi.services.datasource.v1.UpdateDataSourceResponse\"U\x82\xd3\xe4\x93\x02O\x1aJ/v1/datasources/{datasource.metadata.namespace}/{datasource.metadata.name}:\x01*\x12\xdd\x01\n\x10\x44\x65leteDataSource\x12M.github.com.metaprov.modelaapi.services.datasource.v1.DeleteDataSourceRequest\x1aN.github.com.metaprov.modelaapi.services.datasource.v1.DeleteDataSourceResponse\"*\x82\xd3\xe4\x93\x02$*\"/v1/datasources/{namespace}/{name}\x12\xd4\x01\n\x0bInferSchema\x12H.github.com.metaprov.modelaapi.services.datasource.v1.InferSchemaRequest\x1aI.github.com.metaprov.modelaapi.services.datasource.v1.InferSchemaResponse\"0\x82\xd3\xe4\x93\x02*\"(/v1/datasources/{namespace}/{name}:infer\x12\xa7\x01\n\x0cGetTableView\x12I.github.com.metaprov.modelaapi.services.datasource.v1.GetTableViewRequest\x1aJ.github.com.metaprov.modelaapi.services.datasource.v1.GetTableViewResponse\"\x00\x42\x36Z4github.com/metaprov/modelaapi/services/datasource/v1b\x06proto3')



_LISTDATASOURCEREQUEST = DESCRIPTOR.message_types_by_name['ListDataSourceRequest']
_LISTDATASOURCEREQUEST_LABELSENTRY = _LISTDATASOURCEREQUEST.nested_types_by_name['LabelsEntry']
_LISTDATASOURCERESPONSE = DESCRIPTOR.message_types_by_name['ListDataSourceResponse']
_GETDATASOURCEREQUEST = DESCRIPTOR.message_types_by_name['GetDataSourceRequest']
_GETDATASOURCERESPONSE = DESCRIPTOR.message_types_by_name['GetDataSourceResponse']
_UPDATEDATASOURCEREQUEST = DESCRIPTOR.message_types_by_name['UpdateDataSourceRequest']
_UPDATEDATASOURCERESPONSE = DESCRIPTOR.message_types_by_name['UpdateDataSourceResponse']
_CREATEDATASOURCEREQUEST = DESCRIPTOR.message_types_by_name['CreateDataSourceRequest']
_CREATEDATASOURCERESPONSE = DESCRIPTOR.message_types_by_name['CreateDataSourceResponse']
_DELETEDATASOURCEREQUEST = DESCRIPTOR.message_types_by_name['DeleteDataSourceRequest']
_DELETEDATASOURCERESPONSE = DESCRIPTOR.message_types_by_name['DeleteDataSourceResponse']
_INFERSCHEMAREQUEST = DESCRIPTOR.message_types_by_name['InferSchemaRequest']
_INFERSCHEMARESPONSE = DESCRIPTOR.message_types_by_name['InferSchemaResponse']
_GETTABLEVIEWREQUEST = DESCRIPTOR.message_types_by_name['GetTableViewRequest']
_GETTABLEVIEWRESPONSE = DESCRIPTOR.message_types_by_name['GetTableViewResponse']
ListDataSourceRequest = _reflection.GeneratedProtocolMessageType('ListDataSourceRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTDATASOURCEREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.datasource.v1.datasource_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datasource.v1.ListDataSourceRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTDATASOURCEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.datasource.v1.datasource_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datasource.v1.ListDataSourceRequest)
  })
_sym_db.RegisterMessage(ListDataSourceRequest)
_sym_db.RegisterMessage(ListDataSourceRequest.LabelsEntry)

ListDataSourceResponse = _reflection.GeneratedProtocolMessageType('ListDataSourceResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATASOURCERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.datasource.v1.datasource_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datasource.v1.ListDataSourceResponse)
  })
_sym_db.RegisterMessage(ListDataSourceResponse)

GetDataSourceRequest = _reflection.GeneratedProtocolMessageType('GetDataSourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATASOURCEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.datasource.v1.datasource_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datasource.v1.GetDataSourceRequest)
  })
_sym_db.RegisterMessage(GetDataSourceRequest)

GetDataSourceResponse = _reflection.GeneratedProtocolMessageType('GetDataSourceResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDATASOURCERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.datasource.v1.datasource_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datasource.v1.GetDataSourceResponse)
  })
_sym_db.RegisterMessage(GetDataSourceResponse)

UpdateDataSourceRequest = _reflection.GeneratedProtocolMessageType('UpdateDataSourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATASOURCEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.datasource.v1.datasource_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datasource.v1.UpdateDataSourceRequest)
  })
_sym_db.RegisterMessage(UpdateDataSourceRequest)

UpdateDataSourceResponse = _reflection.GeneratedProtocolMessageType('UpdateDataSourceResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATASOURCERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.datasource.v1.datasource_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datasource.v1.UpdateDataSourceResponse)
  })
_sym_db.RegisterMessage(UpdateDataSourceResponse)

CreateDataSourceRequest = _reflection.GeneratedProtocolMessageType('CreateDataSourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATASOURCEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.datasource.v1.datasource_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datasource.v1.CreateDataSourceRequest)
  })
_sym_db.RegisterMessage(CreateDataSourceRequest)

CreateDataSourceResponse = _reflection.GeneratedProtocolMessageType('CreateDataSourceResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATASOURCERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.datasource.v1.datasource_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datasource.v1.CreateDataSourceResponse)
  })
_sym_db.RegisterMessage(CreateDataSourceResponse)

DeleteDataSourceRequest = _reflection.GeneratedProtocolMessageType('DeleteDataSourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATASOURCEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.datasource.v1.datasource_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datasource.v1.DeleteDataSourceRequest)
  })
_sym_db.RegisterMessage(DeleteDataSourceRequest)

DeleteDataSourceResponse = _reflection.GeneratedProtocolMessageType('DeleteDataSourceResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATASOURCERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.datasource.v1.datasource_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datasource.v1.DeleteDataSourceResponse)
  })
_sym_db.RegisterMessage(DeleteDataSourceResponse)

InferSchemaRequest = _reflection.GeneratedProtocolMessageType('InferSchemaRequest', (_message.Message,), {
  'DESCRIPTOR' : _INFERSCHEMAREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.datasource.v1.datasource_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datasource.v1.InferSchemaRequest)
  })
_sym_db.RegisterMessage(InferSchemaRequest)

InferSchemaResponse = _reflection.GeneratedProtocolMessageType('InferSchemaResponse', (_message.Message,), {
  'DESCRIPTOR' : _INFERSCHEMARESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.datasource.v1.datasource_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datasource.v1.InferSchemaResponse)
  })
_sym_db.RegisterMessage(InferSchemaResponse)

GetTableViewRequest = _reflection.GeneratedProtocolMessageType('GetTableViewRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTABLEVIEWREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.datasource.v1.datasource_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datasource.v1.GetTableViewRequest)
  })
_sym_db.RegisterMessage(GetTableViewRequest)

GetTableViewResponse = _reflection.GeneratedProtocolMessageType('GetTableViewResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETTABLEVIEWRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.datasource.v1.datasource_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datasource.v1.GetTableViewResponse)
  })
_sym_db.RegisterMessage(GetTableViewResponse)

_DATASOURCESERVICE = DESCRIPTOR.services_by_name['DataSourceService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z4github.com/metaprov/modelaapi/services/datasource/v1'
  _LISTDATASOURCEREQUEST_LABELSENTRY._options = None
  _LISTDATASOURCEREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _DATASOURCESERVICE.methods_by_name['ListDataSources']._options = None
  _DATASOURCESERVICE.methods_by_name['ListDataSources']._serialized_options = b'\202\323\344\223\002\035\022\033/v1/datasources/{namespace}'
  _DATASOURCESERVICE.methods_by_name['CreateDataSource']._options = None
  _DATASOURCESERVICE.methods_by_name['CreateDataSource']._serialized_options = b'\202\323\344\223\002\024\"\017/v1/datasources:\001*'
  _DATASOURCESERVICE.methods_by_name['GetDataSource']._options = None
  _DATASOURCESERVICE.methods_by_name['GetDataSource']._serialized_options = b'\202\323\344\223\002$\022\"/v1/datasources/{namespace}/{name}'
  _DATASOURCESERVICE.methods_by_name['UpdateDataSource']._options = None
  _DATASOURCESERVICE.methods_by_name['UpdateDataSource']._serialized_options = b'\202\323\344\223\002O\032J/v1/datasources/{datasource.metadata.namespace}/{datasource.metadata.name}:\001*'
  _DATASOURCESERVICE.methods_by_name['DeleteDataSource']._options = None
  _DATASOURCESERVICE.methods_by_name['DeleteDataSource']._serialized_options = b'\202\323\344\223\002$*\"/v1/datasources/{namespace}/{name}'
  _DATASOURCESERVICE.methods_by_name['InferSchema']._options = None
  _DATASOURCESERVICE.methods_by_name['InferSchema']._serialized_options = b'\202\323\344\223\002*\"(/v1/datasources/{namespace}/{name}:infer'
  _LISTDATASOURCEREQUEST._serialized_start=396
  _LISTDATASOURCEREQUEST._serialized_end=647
  _LISTDATASOURCEREQUEST_LABELSENTRY._serialized_start=602
  _LISTDATASOURCEREQUEST_LABELSENTRY._serialized_end=647
  _LISTDATASOURCERESPONSE._serialized_start=650
  _LISTDATASOURCERESPONSE._serialized_end=790
  _GETDATASOURCEREQUEST._serialized_start=792
  _GETDATASOURCEREQUEST._serialized_end=847
  _GETDATASOURCERESPONSE._serialized_start=849
  _GETDATASOURCERESPONSE._serialized_end=972
  _UPDATEDATASOURCEREQUEST._serialized_start=975
  _UPDATEDATASOURCEREQUEST._serialized_end=1134
  _UPDATEDATASOURCERESPONSE._serialized_start=1136
  _UPDATEDATASOURCERESPONSE._serialized_end=1162
  _CREATEDATASOURCEREQUEST._serialized_start=1164
  _CREATEDATASOURCEREQUEST._serialized_end=1275
  _CREATEDATASOURCERESPONSE._serialized_start=1277
  _CREATEDATASOURCERESPONSE._serialized_end=1303
  _DELETEDATASOURCEREQUEST._serialized_start=1305
  _DELETEDATASOURCEREQUEST._serialized_end=1363
  _DELETEDATASOURCERESPONSE._serialized_start=1365
  _DELETEDATASOURCERESPONSE._serialized_end=1391
  _INFERSCHEMAREQUEST._serialized_start=1394
  _INFERSCHEMAREQUEST._serialized_end=1619
  _INFERSCHEMARESPONSE._serialized_start=1621
  _INFERSCHEMARESPONSE._serialized_end=1724
  _GETTABLEVIEWREQUEST._serialized_start=1727
  _GETTABLEVIEWREQUEST._serialized_end=1939
  _GETTABLEVIEWRESPONSE._serialized_start=1941
  _GETTABLEVIEWRESPONSE._serialized_end=2039
  _DATASOURCESERVICE._serialized_start=2042
  _DATASOURCESERVICE._serialized_end=3572
# @@protoc_insertion_point(module_scope)
